pitchtools.MelodicObject
========================

.. inheritance-diagram:: abjad.tools.pitchtools.MelodicObject.MelodicObject.MelodicObject
   :private-bases:

.. autoclass:: abjad.tools.pitchtools.MelodicObject.MelodicObject.MelodicObject

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.MelodicObject.MelodicObject.MelodicObject.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.MelodicObject.MelodicObject.MelodicObject.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.MelodicObject.MelodicObject.MelodicObject.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.MelodicObject.MelodicObject.MelodicObject.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.MelodicObject.MelodicObject.MelodicObject.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.MelodicObject.MelodicObject.MelodicObject.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.MelodicObject.MelodicObject.MelodicObject.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.MelodicObject.MelodicObject.MelodicObject.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
